@@ -1,6 +1,17 @@
-from extras.plugins import PluginMenuButton, PluginMenuItem
+from packaging import version
+
+from django.conf import settings
+from extras.plugins import PluginMenuItem, PluginMenuButton
 from utilities.choices import ButtonColorChoices
 
+# compatibility with netbox v3.3 that does not have PluginMenu
+try:
+    from extras.plugins import PluginMenu
+    HAVE_MENU = True
+except ImportError:
+    HAVE_MENU = False
+    PluginMenu = PluginMenuItem
+
 
 asset_buttons = [
     PluginMenuButton(
@@ -71,7 +82,7 @@ inventoryitemgroup_buttons = [
     ),
 ]
 
-menu_items = (
+menu_buttons = (
     PluginMenuItem(
         link='plugins:netbox_inventory:asset_list',
         link_text='Assets',
@@ -103,3 +114,17 @@ menu_items = (
         buttons=inventoryitemgroup_buttons,
     ),
 )
+
+# can't use utils.get_plugin_setting() here, get value manually
+if (HAVE_MENU and settings.PLUGINS_CONFIG['netbox_inventory']['top_level_menu']):
+    # add a top level entry
+    menu = PluginMenu(
+        label=f'Inventory',
+        groups=(
+            ('Asset Management', menu_buttons),
+        ),
+        icon_class='mdi mdi-clipboard-text-multiple-outline'
+    )
+else:
+    # display under plugins
+    menu_items = menu_buttons
